Learn R Programming

citccmst (version 1.0.2)

cit.centroids: cit.centroids

Description

define centroids for a given partition of individuals (columns) and calculate distance between individuals and centroids

Usage

cit.centroids( d, classes, rowCentering=c(NA,function(x)mean(x, na.rm=TRUE),function(x)median(x, na.rm=TRUE))[[3]], rowClassesForAggregation=NULL, rowClassesToKeep=NULL, dist.meth=c("spearman","euclidian","maximum","manhattan", "canberra","binary","minkowski","pearson","dlda","dqda"), maxDist=0.5, ...)

Arguments

d
a data.frame of numeric data
classes
a vector defining a partition of data columns (NA values accepted)
rowCentering
NA: no row centering; otherwise: function to be used for row centering
rowClassesForAggregation
partition of the rows , used to aggregate rows from the same class (1 aggregated row per class will be calculated)
rowClassesToKeep
to restrict the centroid's calculation to the some aggregated rows (= row classes)
dist.meth
distance method used to calculate distance between individuals (columns in d) and centroids
maxDist
individuals for which nearest centroid is above this threshold are discarted (used only if dis.meth = "pearson" or "spearman")
...
parameters from cit.distToCentroids function

Value

list with two objects : centroids and dist2Centroids