Learn R Programming

citccmst (version 1.0.2)

cit.dist: cit.dist

Description

This function computes and returns the distance matrix computed by using the specified distance measure to compute the distances between the rows of a data matrix.

Usage

cit.dist( x, meth="pearson", use="pairwise.complete.obs", diag=FALSE, upper=FALSE, p=2, replaceNA=TRUE)

Arguments

x
a numeric matrix, data frame or "dist" object.
meth
the distance measure to be used. This must be one of "pearson","spearman","euclidean", "maximum", "manhattan", "canberra", "binary" or "minkowski". Any unambiguous substring can be given.
use
method for computing covariance when NAs, choice between "pairwise.complete.obs", "all.obs" and "complete.obs" (cf cor function parameter)
diag
logical value indicating whether the diagonal of the distance matrix should be printed
upper
logical value indicating whether the upper triangle of the distance matrix should be printed
p
the power of the Minkowski distance.
replaceNA
a boolean indicating if NA value should be replace by

Value

See Also

dist